-- Function returns minimal, maximal and intermediate timestamps
-- of rows in object_metadata table. Number of intermediate timestamps
-- depends on number of parts requested as parameter, for example for
-- 2 parts there will be 3 timestamps returned:
--   timestamp 1 (minimal timestamp)
--   timestamp 2
--   timestamp 3 (maximal timestamp)
-- which split rows into 2 parts: [1, 2] and [2, 3].
-- Returned timestamps split all rows into ranges containing approximately
-- the same number of rows.
CREATE OR REPLACE FUNCTION split_catalog_timestamps(parts_no INTEGER)
RETURNS SETOF TIMESTAMP
AS $$
DECLARE
	rows_count INTEGER;
	part_size INTEGER;
	parts_count INTEGER := parts_no;

	timestamps CURSOR FOR SELECT timestamp FROM object_metadata ORDER BY timestamp ASC;
	ts TIMESTAMP;
BEGIN
	IF parts_no <= 0 THEN 
		RAISE EXCEPTION 'Number of parts must be greater than 0 but was %', parts_no;
	END IF;
	
	SELECT INTO rows_count COUNT(*)
		FROM object_metadata;
	
	IF parts_no > rows_count  THEN
		part_size := 1;
		parts_count := rows_count;
	ELSE
		part_size := rows_count / parts_no;
	END IF;
	
	RETURN QUERY select min(timestamp) from object_metadata;
	
	IF parts_count > 1 THEN
		OPEN timestamps;
	
		FOR counter IN 1 .. parts_count-1 LOOP
			FETCH RELATIVE part_size FROM timestamps INTO ts;
			RETURN NEXT ts;
		END LOOP;
	
		CLOSE timestamps;
	END IF;
	
	RETURN QUERY select max(timestamp) from object_metadata;
	
END;
$$ LANGUAGE plpgsql;
